Crate psyfi_serum_dex_permissioned

Crate psyfi_serum_dex_permissioned 

Re-exports

pub use serum_dex;

Modules

psy_open_book

Macros

open_orders_authority
Returns the seeds used for a user’s open orders account PDA.
open_orders_init_authority
Returns the seeds used for the open orders init authority. This is the account that must sign to create a new open orders account on the DEX market.

Structs

Context
Per request context. Can be used to share data between middleware handlers.
InitAccount
Logger
Logs each request.
MarketProxy
MarketProxy provides an abstraction for implementing proxy programs to the Serum orderbook, allowing one to implement a middleware for the purposes of intercepting and modifying requests before being relayed to the orderbook.
OpenOrdersPda
Checks that the given open orders account signs the transaction and then replaces it with the open orders account, which must be a PDA.
ReferralFees
Enforces referal fees being sent to the configured address.

Enums

ErrorCode

Traits

MarketMiddleware
Implementing this trait allows one to hook into requests to the Serum DEX via a frontend proxy.

Functions

is_valid_dex_id
Returns true if the dex_id is recognized, false otherwise.